@@ -8,7 +8,7 @@
 # @Description :  提供一系列的有关操作mongodb/pymongo的工具
 
 
-__version__ = "0.1.2.3"
+__version__ = "0.1.2.4"
 
 
 import time
@@ -25,7 +25,7 @@ class ManageDB:
     A simple manager class for pymongo
     """
 
-    def __init__(self, host, port):
+    def __init__(self, host="127.0.0.1", port=27017):
         self.host = host
         self.port = port
         self._client = pymongo.MongoClient(host=self.host, port=self.port)
